collective.jsonmigrator's documentation!
==================================================

The purpose of the ``collective.jsonmigrator`` package is to provide a set of
blueprints that help you to migrate content into `Plone`_. (``blueprint`` is
an extension to `collective.transmogrifier`_).

It provides a list of blueprints built around
``collective.jsonmigrator.jsonsource``
with the purpose of providing flexible infrastructure to do migrations in Plone.

And just incase you forgot, migration is a bitch... so have fun :P

.. toctree::
    :titlesonly:

    jsonsource <jsonsource>
    skipitems <skipitems>
    partialcommit <partialcommit>
    statistics <statistics>
    workflowhistory <workflowhistory>
    mimetype <mimetype>
    properties <properties>
    permission_mapping <permission_mapping>
    owner <owner>
    ac_local_roles <ac_local_roles>
    datafields <datafields>

.. _`collective.transmogrifier`: http://pypi.python.org/pypi/collective.transmogrifier
.. _`Plone`: http://plone.org

